@@ -1,20 +1,17 @@
-
 import _ from '_';
 import ko from 'ko';
-import {componentExportHelper} from 'Component/Abstract';
-import {AbstracCheckbox} from 'Component/AbstracCheckbox';
+import { componentExportHelper } from 'Component/Abstract';
+import { AbstractCheckbox } from 'Component/AbstractCheckbox';
 
-class CheckboxMaterialDesignComponent extends AbstracCheckbox
-{
+class CheckboxMaterialDesignComponent extends AbstractCheckbox {
 	/**
 	 * @param {Object} params
 	 */
 	constructor(params) {
-
 		super(params);
 
-		this.animationBox = ko.observable(false).extend({falseTimeout: 200});
-		this.animationCheckmark = ko.observable(false).extend({falseTimeout: 200});
+		this.animationBox = ko.observable(false).extend({ falseTimeout: 200 });
+		this.animationCheckmark = ko.observable(false).extend({ falseTimeout: 200 });
 
 		this.animationBoxSetTrue = _.bind(this.animationBoxSetTrue, this);
 		this.animationCheckmarkSetTrue = _.bind(this.animationCheckmarkSetTrue, this);
@@ -38,8 +35,7 @@ class CheckboxMaterialDesignComponent extends AbstracCheckbox
 		if (box) {
 			this.animationBoxSetTrue();
 			_.delay(this.animationCheckmarkSetTrue, 200);
-		}
-		else {
+		} else {
 			this.animationCheckmarkSetTrue();
 			_.delay(this.animationBoxSetTrue, 200);
 		}
