@@ -1,17 +1,14 @@
-
-import {isUnd} from 'Common/Utils';
-import {componentExportHelper} from 'Component/Abstract';
-import {AbstractInput} from 'Component/AbstractInput';
+import { isUnd } from 'Common/Utils';
+import { componentExportHelper } from 'Component/Abstract';
+import { AbstractInput } from 'Component/AbstractInput';
 
 const DEFAULT_ROWS = 5;
 
-class TextAreaComponent extends AbstractInput
-{
+class TextAreaComponent extends AbstractInput {
 	/**
 	 * @param {Object} params
 	 */
 	constructor(params) {
-
 		super(params);
 
 		this.rows = params.rows || DEFAULT_ROWS;
