@@ -1,16 +1,14 @@
-
 import _ from '_';
 import ko from 'ko';
 
-import {settingsSaveHelperSimpleFunction, boolToAjax, trim} from 'Common/Utils';
-import {settingsGet} from 'Storage/Settings';
+import { settingsSaveHelperSimpleFunction, boolToAjax, trim } from 'Common/Utils';
+import { settingsGet } from 'Storage/Settings';
 
 import AppStore from 'Stores/Admin/App';
 
 import Remote from 'Remote/Admin/Ajax';
 
-class LoginAdminSettings
-{
+class LoginAdminSettings {
 	constructor() {
 		this.determineUserLanguage = AppStore.determineUserLanguage;
 		this.determineUserDomain = AppStore.determineUserDomain;
@@ -52,4 +50,4 @@ class LoginAdminSettings
 	}
 }
 
-export {LoginAdminSettings, LoginAdminSettings as default};
+export { LoginAdminSettings, LoginAdminSettings as default };
