@@ -1,6 +1,5 @@
-
 import window from 'window';
-import {isUnd, isNormal, isArray, inArray} from 'Common/Utils';
+import { isUnd, isNormal, isArray, inArray } from 'Common/Utils';
 
 let SETTINGS = window.__rlah_data() || null;
 SETTINGS = isNormal(SETTINGS) ? SETTINGS : {};
@@ -12,8 +11,7 @@ APP_SETTINGS = isNormal(APP_SETTINGS) ? APP_SETTINGS : {};
  * @param {string} name
  * @returns {*}
  */
-export function settingsGet(name)
-{
+export function settingsGet(name) {
 	return isUnd(SETTINGS[name]) ? null : SETTINGS[name];
 }
 
@@ -21,8 +19,7 @@ export function settingsGet(name)
  * @param {string} name
  * @param {*} value
  */
-export function settingsSet(name, value)
-{
+export function settingsSet(name, value) {
 	SETTINGS[name] = value;
 }
 
@@ -30,8 +27,7 @@ export function settingsSet(name, value)
  * @param {string} name
  * @returns {*}
  */
-export function appSettingsGet(name)
-{
+export function appSettingsGet(name) {
 	return isUnd(APP_SETTINGS[name]) ? null : APP_SETTINGS[name];
 }
 
@@ -39,8 +35,7 @@ export function appSettingsGet(name)
  * @param {string} name
  * @returns {boolean}
  */
-export function capa(name)
-{
+export function capa(name) {
 	const values = settingsGet('Capa');
 	return isArray(values) && isNormal(name) && -1 < inArray(name, values);
 }
