@@ -1,8 +1,6 @@
-
 import ko from 'ko';
 
-class CoreAdminStore
-{
+class CoreAdminStore {
 	constructor() {
 		this.coreReal = ko.observable(true);
 		this.coreChannel = ko.observable('stable');
@@ -10,8 +8,8 @@ class CoreAdminStore
 		this.coreUpdatable = ko.observable(true);
 		this.coreAccess = ko.observable(true);
 		this.coreWarning = ko.observable(false);
-		this.coreChecking = ko.observable(false).extend({throttle: 100});
-		this.coreUpdating = ko.observable(false).extend({throttle: 100});
+		this.coreChecking = ko.observable(false).extend({ throttle: 100 });
+		this.coreUpdating = ko.observable(false).extend({ throttle: 100 });
 		this.coreVersion = ko.observable('');
 		this.coreRemoteVersion = ko.observable('');
 		this.coreRemoteRelease = ko.observable('');
