@@ -1,11 +1,9 @@
-
 import ko from 'ko';
 import _ from '_';
-import {Magics} from 'Common/Enums';
+import { Magics } from 'Common/Enums';
 import * as Settings from 'Storage/Settings';
 
-class AccountUserStore
-{
+class AccountUserStore {
 	constructor() {
 		this.email = ko.observable('');
 		this.parentEmail = ko.observable('');
@@ -13,14 +11,13 @@ class AccountUserStore
 		this.signature = ko.observable('');
 
 		this.accounts = ko.observableArray([]);
-		this.accounts.loading = ko.observable(false).extend({throttle: Magics.Time100ms});
+		this.accounts.loading = ko.observable(false).extend({ throttle: Magics.Time100ms });
 
 		this.computers();
 	}
 
 	computers() {
-		this.accountsEmails = ko.computed(
-			() => _.compact(_.map(this.accounts(), (item) => (item ? item.email : null))));
+		this.accountsEmails = ko.computed(() => _.compact(_.map(this.accounts(), (item) => (item ? item.email : null))));
 
 		this.accountsUnreadCount = ko.computed(() => 0);
 		// this.accountsUnreadCount = ko.computed(() => {
