@@ -1,6 +1,3 @@
-
-/* global RL_COMMUNITY */
-
 import ko from 'ko';
 
 import * as Settings from 'Storage/Settings';
@@ -11,18 +8,17 @@ import DomainStore from 'Stores/Admin/Domain';
 import PluginStore from 'Stores/Admin/Plugin';
 import PackageStore from 'Stores/Admin/Package';
 
-import {getApp} from 'Helper/Apps/Admin';
+import { getApp } from 'Helper/Apps/Admin';
 
-import {view, ViewType} from 'Knoin/Knoin';
-import {AbstractViewNext} from 'Knoin/AbstractViewNext';
+import { view, ViewType } from 'Knoin/Knoin';
+import { AbstractViewNext } from 'Knoin/AbstractViewNext';
 
 @view({
 	name: 'View/Admin/Settings/Pane',
 	type: ViewType.Right,
 	templateID: 'AdminPane'
 })
-class PaneSettingsAdminView extends AbstractViewNext
-{
+class PaneSettingsAdminView extends AbstractViewNext {
 	constructor() {
 		super();
 
@@ -33,16 +29,18 @@ class PaneSettingsAdminView extends AbstractViewNext
 		this.community = RL_COMMUNITY;
 
 		this.adminManLoading = ko.computed(
-			() => '000' !== [
-				DomainStore.domains.loading() ? '1' : '0',
-				PluginStore.plugins.loading() ? '1' : '0',
-				PackageStore.packages.loading() ? '1' : '0'
-			].join('')
+			() =>
+				'000' !==
+				[
+					DomainStore.domains.loading() ? '1' : '0',
+					PluginStore.plugins.loading() ? '1' : '0',
+					PackageStore.packages.loading() ? '1' : '0'
+				].join('')
 		);
 
-		this.adminManLoadingVisibility = ko.computed(
-			() => (this.adminManLoading() ? 'visible' : 'hidden')
-		).extend({rateLimit: 300});
+		this.adminManLoadingVisibility = ko
+			.computed(() => (this.adminManLoading() ? 'visible' : 'hidden'))
+			.extend({ rateLimit: 300 });
 	}
 
 	logoutClick() {
@@ -52,4 +50,4 @@ class PaneSettingsAdminView extends AbstractViewNext
 	}
 }
 
-export {PaneSettingsAdminView, PaneSettingsAdminView as default};
+export { PaneSettingsAdminView, PaneSettingsAdminView as default };
