@@ -1,22 +1,20 @@
-
 import ko from 'ko';
 
 import * as Settings from 'Storage/Settings';
 
-import {view, ViewType} from 'Knoin/Knoin';
-import {AbstractViewNext} from 'Knoin/AbstractViewNext';
+import { view, ViewType } from 'Knoin/Knoin';
+import { AbstractViewNext } from 'Knoin/AbstractViewNext';
 
 @view({
 	name: 'View/User/About',
 	type: ViewType.Center,
 	templateID: 'About'
 })
-class AboutUserView extends AbstractViewNext
-{
+class AboutUserView extends AbstractViewNext {
 	constructor() {
 		super();
 		this.version = ko.observable(Settings.appSettingsGet('version'));
 	}
 }
 
-export {AboutUserView, AboutUserView as default};
+export { AboutUserView, AboutUserView as default };
